##  Tag Scoped Applications
As you will most likely approach the assessment iteratively, we recommend tagging these applications accordingly. Tagging your applications helps you to narrow down your views, reports, surveys, and dashboards to the desired view more easily than filtering manually each time. Tags also keep the fact sheet data clean, as they are not an attribute or data field and can be removed once the initiative is over.
Suggested tag: application rationalization
![Screenshot of the inventory in table view showing the tags column with the tag "Use Case: Rationalization"](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio55aad627192948aa9f2ed915a5354ba4_HiRes.png)
YesNo
Send
![close icon](https://consent.trustarc.com/get?name=sapglow-close-icon.png)
This site uses cookies and related technologies, as described in our Cookie Statement, for purposes that may include site operation, analytics, enhanced user experience, or advertising. You may choose to consent to our use of these technologies, or manage your own preferences.
Understood Manage Settings
[Privacy Statement](https://help.sap.com/docs/privacy)|[Cookie Statement](https://www.sap.com/about/legal/privacy/cookies.html)
